.. py:currentmodule:: drdmannturb

Internal Neural Network Interfaces
==================================

.. autoclass:: drdmannturb.TauNet 
    :members:

.. autoclass:: drdmannturb.CustomNet
    :members:

.. autoclass:: drdmannturb.SimpleNN
    :members:

.. autoclass:: drdmannturb.Rational
    :members:

.. autoclass:: drdmannturb.CustomMLP
    :members: